@@ -119,6 +119,8 @@ $INSTALL -d -m 755 "$DESTDIR/usr/share/laptop-mode-tools/module-helpers"
 $INSTALL -d -m 755 "$DESTDIR/etc/laptop-mode/conf.d"
 $INSTALL -d -m 755 "$DESTDIR/etc/laptop-mode/modules"
 $INSTALL -d -m 755 "$DESTDIR/usr/share/polkit-1/actions"
+$INSTALL -d -m 755 "$DESTDIR/usr/share/applications"
+$INSTALL -d -m 755 "$DESTDIR/usr/share/pixmaps"
 $INSTALL -d -m 755 "$DESTDIR/usr/sbin"
 $INSTALL -d -m 755 "$DESTDIR/$UDEV_D/rules.d"
 $INSTALL -d -m 755 "$DESTDIR/$MAN_D/man8"
@@ -192,6 +194,25 @@ if ( ! $INSTALL -m 744 man/* "$DESTDIR/$MAN_D/man8" ) ; then
 	exit 23
 fi
 
+if ( ! $INSTALL -m 644 gui/laptop-mode-tools.desktop "$DESTDIR/usr/share/applications" ) ; then
+	echo "$0: Failed to install $DESTDIR/usr/share/applications/laptop-mode-tools.desktop"
+	exit 11
+fi
+
+if ( ! $INSTALL -m 755 gui/lmt-config-gui* "$DESTDIR/usr/sbin" ) ; then
+	echo "$0: Failed to install $DESTDIR/usr/sbin/lmt-config-gui*"
+	exit 11
+fi
+
+if ( ! $INSTALL -m 644 gui/laptop-mode-tools.svg "$DESTDIR/usr/share/pixmaps" ) ; then
+	echo "$0: Failed to install $DESTDIR/usr/share/pixmaps/laptop-mode-tools.svg";
+	exit 11
+fi
+
+if ( ! $INSTALL -m 644 gui/LMT.py "$DESTDIR/usr/share/laptop-mode-tools" ) ; then
+	echo "$0: Failed to install $DESTDIR/usr/share/laptop-mode-tools/lmt.py";
+	exit 11
+fi
 
 # Install pm-utils hook only if pm-utils config dir is present, or force the
 # install if we have a DESTDIR.
